@@ -30,10 +30,12 @@
 namespace Drawing {
 
     void drawCoverage(const Themes::IniOptions &opts, std::vector<Segs::ReadCollection> &collections,
-                      SkCanvas *canvas, const Themes::Fonts &fonts, float covY, float refSpace, const float gap);
+                      SkCanvas *canvas, const Themes::Fonts &fonts, float covY, float refSpace, float gap,
+                      float monitorScale, std::vector<std::string> &bam_paths);
 
     void drawCollection(const Themes::IniOptions &opts, Segs::ReadCollection &cl, SkCanvas* canvas,
-                  float trackY, float yScaling, const Themes::Fonts &fonts, int linkOp, float refSpace, float pointSlop, float textDrop, float pH, float monitorScale);
+                  float trackY, float yScaling, const Themes::Fonts &fonts, int linkOp, float refSpace, float pointSlop,
+                  float textDrop, float pH, float monitorScale, std::vector<std::string> &bam_paths);
 
     void drawRef(const Themes::IniOptions &opts, std::vector<Utils::Region> &regions, int fb_width,
                  SkCanvas *canvas, const Themes::Fonts &fonts, float refSpace, float nRegions, float gap, float monitorScale, bool scale_bar);
