@@ -360,7 +360,8 @@ namespace HGW {
                           float pointSlop,
                           float textDrop,
                           float pH,
-                          float monitorScale) {
+                          float monitorScale,
+                          std::vector<std::string> &bam_paths) {
         const int BATCH = 1500;
         bam1_t *src;
         hts_itr_t *iter_q;
@@ -419,7 +420,10 @@ namespace HGW {
 
             Segs::findYNoSortForward(readQueue, col.levelsStart, col.levelsEnd, col.vScroll);
 
-            Drawing::drawCollection(opts, col, canvas, trackY, yScaling, fonts, opts.link_op, refSpace, pointSlop, textDrop, pH, monitorScale);
+            if (opts.alignments) {
+                Drawing::drawCollection(opts, col, canvas, trackY, yScaling, fonts, opts.link_op, refSpace, pointSlop,
+                                        textDrop, pH, monitorScale, bam_paths);
+            }
 
             for (int i=0; i < BATCH; ++ i) {
                 Segs::align_clear(&readQueue[i]);
@@ -443,7 +447,9 @@ namespace HGW {
                     }
                 }
                 Segs::findYNoSortForward(readQueue, col.levelsStart, col.levelsEnd, col.vScroll);
-                Drawing::drawCollection(opts, col, canvas, trackY, yScaling, fonts, opts.link_op, refSpace, pointSlop, textDrop, pH, monitorScale);
+                Drawing::drawCollection(opts, col, canvas, trackY, yScaling, fonts, opts.link_op, refSpace, pointSlop,
+                                        textDrop, pH, monitorScale, bam_paths);
+
                 for (int i=0; i < BATCH; ++ i) {
                     Segs::align_clear(&readQueue[i]);
                 }
@@ -456,7 +462,8 @@ namespace HGW {
                   bool coverage,
                   std::vector<Parse::Parser> &filters, Themes::IniOptions &opts, SkCanvas *canvas,
                   float trackY, float yScaling, Themes::Fonts &fonts, float refSpace,
-                  float pointSlop, float textDrop, float pH, float monitorScale) {
+                  float pointSlop, float textDrop, float pH, float monitorScale,
+                  std::vector<std::string> &bam_paths) {
 
         bam1_t *src;
         hts_itr_t *iter_q;
@@ -499,7 +506,8 @@ namespace HGW {
                 Segs::addToCovArray(col.covArr, readQueue.back(), region->start, region->end, l_arr);
             }
             Segs::alignFindYForward(readQueue.back(), col.levelsStart, col.levelsEnd, col.vScroll);
-            Drawing::drawCollection(opts, col, canvas, trackY, yScaling, fonts, opts.link_op, refSpace, pointSlop, textDrop, pH, monitorScale);
+            Drawing::drawCollection(opts, col, canvas, trackY, yScaling, fonts, opts.link_op, refSpace, pointSlop,
+                                    textDrop, pH, monitorScale, bam_paths);
             Segs::align_clear(&readQueue.back());
         }
     }
@@ -543,11 +551,11 @@ namespace HGW {
             for (auto &i : col.readQueue) {
                 Segs::addToCovArray(col.covArr, i, region->start, region->end, l_arr);
             }
-            if (snp_threshold > region->end - region->start) {
-                col.mmVector.resize(region->end - region->start + 1);
-                Segs::Mismatches empty_mm{};
-                std::fill(col.mmVector.begin(), col.mmVector.end(), empty_mm);
-            }
+        }
+        if (snp_threshold > region->end - region->start) {
+            col.mmVector.resize(region->end - region->start + 1);
+            Segs::Mismatches empty_mm{};
+            std::fill(col.mmVector.begin(), col.mmVector.end(), empty_mm);
         }
     }
 
@@ -633,13 +641,13 @@ namespace HGW {
                         for (auto &i : readQueue) {
                             Segs::addToCovArray(col.covArr, i, region->start, region->end, l_arr);
                         }
-                        if (opts.snp_threshold > region->end - region->start) {
-                            col.mmVector.resize(region->end - region->start + 1);
-                            Segs::Mismatches empty_mm{};
-                            std::fill(col.mmVector.begin(), col.mmVector.end(), empty_mm);
-                        } else {
-                            col.mmVector.clear();
-                        }
+                    }
+                    if (opts.snp_threshold > region->end - region->start) {
+                        col.mmVector.resize(region->end - region->start + 1);
+                        Segs::Mismatches empty_mm{};
+                        std::fill(col.mmVector.begin(), col.mmVector.end(), empty_mm);
+                    } else {
+                        col.mmVector.clear();
                     }
                     col.collection_processed = false;
                     return;
@@ -766,23 +774,19 @@ namespace HGW {
 
         }
         if (coverage) {  // re process coverage for all reads
-//            auto start = std::chrono::high_resolution_clock::now();
             col.covArr.resize(region->end - region->start + 1);
             std::fill(col.covArr.begin(), col.covArr.end(), 0);
             int l_arr = (int)col.covArr.size() - 1;
             for (auto &i : readQueue) {
                 Segs::addToCovArray(col.covArr, i, region->start, region->end, l_arr);
             }
-            if (opts.snp_threshold > region->end - region->start) {
-                col.mmVector.resize(region->end - region->start + 1);
-                Segs::Mismatches empty_mm{};
-                std::fill(col.mmVector.begin(), col.mmVector.end(), empty_mm);
-            } else {
-                col.mmVector.clear();
-            }
-//            auto stop = std::chrono::high_resolution_clock::now();
-//            auto duration = std::chrono::duration_cast<std::chrono::microseconds>(stop - start).count();
-//            std::cerr << " resizing and stuff! " << duration << std::endl;
+        }
+        if (opts.snp_threshold > region->end - region->start) {
+            col.mmVector.resize(region->end - region->start + 1);
+            Segs::Mismatches empty_mm{};
+            std::fill(col.mmVector.begin(), col.mmVector.end(), empty_mm);
+        } else {
+            col.mmVector.clear();
         }
         col.collection_processed = false;
     }
@@ -1489,6 +1493,7 @@ namespace HGW {
                 b.vartype = b.parts[2];
                 b.start = std::stoi(b.parts[3]) - 1;
                 b.end = std::stoi(b.parts[4]);
+
                 if (b.parts[6] == "+") {
                     b.strand = 1;
                 } else if (b.parts[6] == "-") {
@@ -1505,11 +1510,12 @@ namespace HGW {
                             if (!b.parent.empty()) {
                                 break;
                             }
-                        }
-                        else if (b.name.empty() && keyval[0] == "ID") {
+                        } else if (b.name.empty() && keyval[0] == "ID") {
                             b.name = keyval[1];
-                        }
-                        else if (keyval[0] == "Parent") {
+                            if (b.parent.empty()) {
+                                b.parent = keyval[1];
+                            }
+                        } else if (keyval[0] == "Parent") {
                             b.parent = keyval[1];
                             b.name = keyval[1];
                         }
@@ -2371,11 +2377,14 @@ namespace HGW {
                 track.s.push_back(g->start);
                 track.e.push_back(g->end);
 
-                if (g->vartype == "CDS") { // g->vartype == "exon" ||
+                if (g->vartype == "CDS") {
                     track.anyToDraw = true;
                     track.drawThickness.push_back(2);  // fat line
+                } else if (g->vartype == "gene") {
+                    track.drawThickness.push_back(3);  // border only
                 } else if (g->vartype == "mRNA" || g->vartype == "gene" || g->vartype == "exon") {
                     track.drawThickness.push_back(0);  // no line
+                    if (!track.anyToDraw) { track.anyToDraw = true; }
                 } else if (g->vartype == "start_codon") {
                     between_codons = !between_codons;
                     track.coding_start = g->start;
