@@ -49,11 +49,11 @@ namespace Menu {
 
     std::vector<std::string> getCommandTip();
 
-    constexpr std::array<const char*, 29> commandToolTip = {"ylim", "var", "tlen-y", "tags", "sort", "soft-clips", "save", "sam", "remove",
+    constexpr std::array<const char*, 30> commandToolTip = {"ylim", "var", "tlen-y", "tags", "sort", "soft-clips", "save", "sam", "remove",
                                                             "refresh", "online", "mods", "mismatches", "mate", "mate add", "log2-cov", "load", "link", "line", "insertions", "indel-length",
-                                                            "grid", "find", "filter", "expand-tracks", "edges", "cov",  "count", "add"};
+                                                            "grid", "find", "filter", "expand-tracks", "edges", "cov",  "count", "alignments", "add"};
 
-    constexpr std::array<const char*, 16> exec = {"cov", "count", "edges", "expand-tracks", "insertions", "line", "log2-cov", "mate", "mate add", "mismatches", "mods", "tags", "soft-clips", "sam", "refresh", "tlen-y"};
+    constexpr std::array<const char*, 17> exec = {"alignments", "cov", "count", "edges", "expand-tracks", "insertions", "line", "log2-cov", "mate", "mate add", "mismatches", "mods", "tags", "soft-clips", "sam", "refresh", "tlen-y"};
 
     int getCommandSwitchValue(Themes::IniOptions &opts, std::string &cmd_s, bool &drawLine);
 
