@@ -4,7 +4,6 @@
 
 #include <array>
 #include <iomanip>
-#include <iterator>
 #include <cstdlib>
 #include <cstdio>
 #include <string>
@@ -17,10 +16,8 @@
 #include <htslib/bgzf.h>
 #include <htslib/hfile.h>
 #include <htslib/cram.h>
-#include <GLFW/glfw3.h>
 #include <hts_funcs.h>
 #include <filesystem>
-#include <GLFW/glfw3.h>
 #include <iostream>
 
 #if defined(_WIN32)
@@ -35,12 +32,22 @@
 #include "themes.h"
 
 
+#include "include/core/SkCanvas.h"
+#include "include/core/SkSurface.h"
+#include "include/core/SkDocument.h"
+#include "include/docs/SkPDFDocument.h"
+#include "include/core/SkStream.h"
+#include "include/core/SkPictureRecorder.h"
+#include "include/core/SkPicture.h"
+#include "include/svg/SkSVGCanvas.h"
+
+
 /* Notes for adding new commands:
  * 1. Make a new function, accepting a pointer to a GwPlot instance and any other args
  * 2. Add function to run_command_map below
  * 3. Add documentation in term_out.cpp - quick help in menu.cpp text as well as a manual in term_out.cpp
  * 4. Register command in the menu functions if needed:
- *     register with optionFromStr fucntion
+ *     register with optionFromStr function
  *     add to relevant functions
  *         getCommandSwitchValue applyBoolOption, applyKeyboardKeyOption etc
  *     add a tool tip in drawMenu
@@ -104,12 +111,21 @@ namespace Commands {
     Err refreshGw(Plot* p) {
         p->redraw = true;
         p->processed = false;
-        p->imageCache.clear();
-        p->imageCacheQueue.clear();
-        p->filters.clear();
-        p->target_qname = "";
-        for (auto &cl: p->collections) { cl.vScroll = 0; cl.skipDrawingCoverage = false; cl.skipDrawingReads = false; }
-        for (auto &rgn: p->regions) { rgn.sortOption = Utils::SortType::NONE, rgn.sortPos = -1; rgn.refBaseAtPos = '\0'; }
+        if (p->frameId > 0) {
+            p->imageCache.clear();
+            p->imageCacheQueue.clear();
+            p->filters.clear();
+            p->target_qname = "";
+            for (auto &cl: p->collections) {
+                cl.vScroll = 0;
+                cl.skipDrawingCoverage = false;
+                cl.skipDrawingReads = false;
+            }
+            for (auto &rgn: p->regions) {
+                rgn.sortOption = Utils::SortType::NONE, rgn.sortPos = -1;
+                rgn.refBaseAtPos = '\0';
+            }
+        }
         return Err::NONE;
     }
 
@@ -267,18 +283,20 @@ namespace Commands {
 
     Err log2_cov(Plot* p) {
         p->opts.log2_cov = !(p->opts.log2_cov);
-        p->redraw = true;
-        if (p->mode == Manager::Show::SINGLE) {
-            p->processed = true;
-            for (auto &cl : p->collections) {
-                cl.skipDrawingReads = false;
-                cl.skipDrawingCoverage = false;
+        if (p->frameId > 0) {
+            p->redraw = true;
+            if (p->mode == Manager::Show::SINGLE) {
+                p->processed = true;
+                for (auto &cl : p->collections) {
+                    cl.skipDrawingReads = false;
+                    cl.skipDrawingCoverage = false;
+                }
+            } else {
+                p->processed = false;
             }
-        } else {
-            p->processed = false;
+            p->imageCache.clear();
+            p->imageCacheQueue.clear();
         }
-        p->imageCache.clear();
-        p->imageCacheQueue.clear();
         return Err::NONE;
     }
 
@@ -303,6 +321,30 @@ namespace Commands {
         return Err::NONE;
     }
 
+    Err alignments(Plot* p) {
+        p->opts.alignments = !p->opts.alignments;
+        if (p->frameId > 0) {
+            for (auto &cl: p->collections) {
+                cl.skipDrawingCoverage = false;
+                cl.skipDrawingReads = false;
+            }
+            p->redraw = true;
+        }
+        return Err::NONE;
+    }
+
+    Err labels(Plot* p) {
+        p->opts.data_labels = !p->opts.data_labels;
+        if (p->frameId > 0) {
+            for (auto &cl: p->collections) {
+                cl.skipDrawingCoverage = false;
+                cl.skipDrawingReads = false;
+            }
+            p->redraw = true;
+        }
+        return Err::NONE;
+    }
+
     Err link(Plot* p, std::string& command, std::vector<std::string>& parts) {
         bool relink = false;
         if (command == "link" || command == "link all") {
@@ -320,7 +362,7 @@ namespace Commands {
                 p->opts.link = "none";
             }
         }
-        if (relink) {
+        if (relink && p->frameId > 0) {
             p->imageCache.clear();
             p->imageCacheQueue.clear();
             HGW::refreshLinked(p->collections, p->regions, p->opts, &p->samMaxY);
@@ -417,14 +459,15 @@ namespace Commands {
                 out << command << std::endl;
             }
         }
-        p->imageCache.clear();
-        p->imageCacheQueue.clear();
-        p->processed = false;
+        if (p->frameId > 0) {
+            p->imageCache.clear();
+            p->imageCacheQueue.clear();
+            p->processed = false;
+        }
         return Err::NONE;
     }
 
     Err tags(Plot* p, std::string& command, std::ostream& out) {
-        p->redraw = false;
         if (!p->selectedAlign.empty()) {
             std::string str = command;
             str.erase(0, 4);
@@ -454,7 +497,10 @@ namespace Commands {
                 out << std::endl;
             }
         }
-        p->processed = true;
+        if (p->frameId > 0) {
+            p->processed = true;
+            p->redraw = false;
+        }
         return Err::NONE;
     }
 
@@ -549,9 +595,11 @@ namespace Commands {
             return Err::NONE;
         }
         p->opts.indel_length = indel_length;
-        p->processed = false;
-        p->imageCache.clear();
-        p->imageCacheQueue.clear();
+        if (p->frameId > 0) {
+            p->processed = false;
+            p->imageCache.clear();
+            p->imageCacheQueue.clear();
+        }
         return Err::NONE;
     }
 
@@ -637,14 +685,16 @@ namespace Commands {
                 return Err::NONE;
             }
         }
-        for (auto &cl : p->collections) {
-            cl.skipDrawingReads = false;
-            cl.skipDrawingCoverage = false;
-        }
         p->opts.max_coverage = std::max(0, p->opts.max_coverage);
-        p->processed = false;
-        p->imageCache.clear();
-        p->imageCacheQueue.clear();
+        if (p->frameId > 0) {
+            for (auto &cl: p->collections) {
+                cl.skipDrawingReads = false;
+                cl.skipDrawingCoverage = false;
+            }
+            p->processed = false;
+            p->imageCache.clear();
+            p->imageCacheQueue.clear();
+        }
         return Err::NONE;
     }
 
@@ -734,9 +784,11 @@ namespace Commands {
         } catch (...) {
             return Err::PARSE_INPUT;
         }
-        p->processed = false;
-        p->imageCache.clear();
-        p->imageCacheQueue.clear();
+        if (p->frameId > 0) {
+            p->processed = false;
+            p->imageCache.clear();
+            p->imageCacheQueue.clear();
+        }
         return Err::NONE;
     }
 
@@ -771,10 +823,15 @@ namespace Commands {
             }
         }
         p->regions.insert(p->regions.end(), new_regions.begin(), new_regions.end());
-        p->processed = false;
-        for (auto &cl: p->collections) { cl.skipDrawingCoverage = false; cl.skipDrawingReads = false;}
-        p->imageCache.clear();
-        p->imageCacheQueue.clear();
+        if (p->frameId > 0) {
+            p->processed = false;
+            for (auto &cl: p->collections) {
+                cl.skipDrawingCoverage = false;
+                cl.skipDrawingReads = false;
+            }
+            p->imageCache.clear();
+            p->imageCacheQueue.clear();
+        }
         return Err::NONE;
     }
 
@@ -785,7 +842,7 @@ namespace Commands {
         }
         std::string fname;
         p->currentVarTrack = &p->variantTracks[p->variantFileSelection];
-        if (parts.size() == 1) {
+        if (parts.size() == 1) {  // Choose filename automatically based on region
             if (p->mode == Manager::Show::SINGLE) {
                 std::filesystem::path fname_path = Utils::makeFilenameFromRegions(p->regions);
 #if defined(_WIN32) || defined(_WIN64)
@@ -802,6 +859,7 @@ namespace Commands {
             }
         } else {
             std::string nameFormat = parts[1];
+            // try and parse information from vcf record e.g. {pos}.png
             if (p->currentVarTrack != nullptr && p->currentVarTrack->type == HGW::TrackType::VCF && p->mode == Manager::Show::SINGLE) {
                 if (p->mouseOverTileIndex == -1 || p->currentVarTrack->blockStart + p->mouseOverTileIndex > (int) p->currentVarTrack->multiLabels.size()) {
                     return Err::SILENT;
@@ -831,10 +889,50 @@ namespace Commands {
             out << termcolor::red << "Error:" << termcolor::reset << " path not found " << out_path.parent_path() << std::endl;
             return Err::INVALID_PATH;
         } else {
-            if (!p->imageCacheQueue.empty()) {
-                Manager::imagePngToFile(p->imageCacheQueue.back().second, out_path.string());
-                Term::clearLine(out);
+            if (out_path.extension() == ".png") {
+                if (!p->imageCacheQueue.empty()) {
+                    Manager::imagePngToFile(p->imageCacheQueue.back().second, out_path.string());
+                    Term::clearLine(out);
+                    out << "\rSaved to " << out_path << std::endl;
+                }
+            } else if (out_path.extension() == ".pdf" || out_path.extension() == ".svg") {
+                std::string format_str = (out_path.extension() == ".pdf") ? "pdf" : "svg";
+
+#if defined(_WIN32) || defined(_WIN64)
+                const wchar_t* outp = out_path.c_str();
+                std::wstring pw(outp);
+                std::string outp_str(pw.begin(), pw.end());
+                SkFILEWStream out_stream(outp_str.c_str());
+#else
+                SkFILEWStream out_stream(out_path.c_str());
+#endif
+                SkDynamicMemoryWStream buffer;
+
+                for (auto &cl: p->collections) {
+                    cl.skipDrawingCoverage = false;
+                    cl.skipDrawingReads = false;
+                }
+                if (format_str == "pdf") {
+                    auto pdfDocument = SkPDF::MakeDocument(&buffer);
+                    SkCanvas *pageCanvas = pdfDocument->beginPage(p->fb_width, p->fb_height);
+                    p->runDrawOnCanvas(pageCanvas);
+                    pdfDocument->close();
+                    buffer.writeToStream(&out_stream);
+                } else {
+                    SkPictureRecorder recorder;
+                    SkCanvas* canvas = recorder.beginRecording(SkRect::MakeWH(p->fb_width, p->fb_height));
+                    p->runDrawOnCanvas(canvas);
+                    sk_sp<SkPicture> picture = recorder.finishRecordingAsPicture();
+                    std::unique_ptr<SkCanvas> svgCanvas = SkSVGCanvas::Make(SkRect::MakeWH(p->fb_width, p->fb_height), &out_stream);
+                    if (svgCanvas) {
+                        picture->playback(svgCanvas.get());
+                        svgCanvas->flush();
+                    };
+                }
                 out << "\rSaved to " << out_path << std::endl;
+            } else {
+                out << termcolor::red << "Error:" << termcolor::reset << " extension not supported " << out_path.extension() << std::endl;
+                return Err::OPTION_NOT_SUPPORTED;
             }
         }
         return Err::NONE;
@@ -1049,16 +1147,12 @@ namespace Commands {
             } else {
                 return Err::OPTION_NOT_UNDERSTOOD;
             }
-        }
-        //  Err snapshot(Plot* p, std::vector<std::string> parts, std::ostream& out) {
-        else if (Utils::endsWith(command, ".png")) {
+        } else if (Utils::endsWith(command, ".png") || Utils::endsWith(command, ".pdf") || Utils::endsWith(command, ".svg")) {
             return snapshot(p, parts, out);
-        }
-        else if (Utils::endsWith(parts.back(), ".ini")) {
+        } else if (Utils::endsWith(parts.back(), ".ini")) {
             out << "Saved session: " << parts.back() << std::endl;
             p->saveSession(parts.back());
-        }
-        else if (Utils::endsWith(parts.back(), ".tsv") || (Utils::endsWith(parts.back(), ".txt"))) {
+        } else if (Utils::endsWith(parts.back(), ".tsv") || (Utils::endsWith(parts.back(), ".txt"))) {
             out << "Output label file set as: " << parts.back() << std::endl;
             p->setOutLabelFile(parts.back());
             p->saveLabels();
@@ -1231,6 +1325,7 @@ namespace Commands {
             if (res <= 0) {
                 p->redraw = true;
                 int num_sequences = faidx_nseq(p->fai);
+                out << "Error: Command not understood\n";
                 out << "Chromosome names in the fasta index:" << std::endl;
                 for (int i = 0; i < num_sequences; ++i) {
                     const char* seq_name = faidx_iseq(p->fai, i);
@@ -1284,7 +1379,7 @@ namespace Commands {
                 }
             }
         }
-        if (reason == Err::NONE) {
+        if (reason == Err::NONE && p->frameId > 0) {
             p->processed = false;
             p->imageCache.clear();
             p->redraw = true;
@@ -1392,7 +1487,6 @@ namespace Commands {
             SkPaint new_paint;
             new_paint.setARGB(alpha, red, green, blue);
             p->tracks[ind].setPaint(new_paint);
-//            p->tracks[ind].faceColour.setARGB(alpha, red, green, blue);
             refreshGw(p);
             return Err::NONE;
         }
@@ -1652,6 +1746,8 @@ namespace Commands {
                 {"log2-cov",  PARAMS { return log2_cov(p); }},
                 {"expand-tracks", PARAMS { return expand_tracks(p); }},
                 {"tlen-y",   PARAMS { return tlen_y(p); }},
+                {"alignments",   PARAMS { return alignments(p); }},
+                {"labels",   PARAMS { return labels(p); }},
 
                 {"sam",      PARAMS { return sam(p, command, parts, out); }},
                 {"h",        PARAMS { return getHelp(p, command, parts, out); }},
