@@ -258,6 +258,10 @@ namespace Manager {
         glfwWindowHint(GLFW_CONTEXT_VERSION_MAJOR, (major_v == -1) ? 4 : major_v);
         glfwWindowHint(GLFW_CONTEXT_VERSION_MINOR, (minor_v == -1) ? 1 : major_v);
 #endif
+        if (debug) {
+            std::cerr << "Creating window with size " << width << "x" << height << std::endl;
+        }
+
         window = glfwCreateWindow(width, height, "GW", NULL, NULL);
 
         if (!window) {
@@ -327,12 +331,14 @@ namespace Manager {
             if (!gladLoadGLLoader((GLADloadproc) glfwGetProcAddress)) {
                 std::cerr << "Error: failed to initialize GLAD GL\n";
             }
-            if (GLAD_GL_VERSION_4_1) {
-                std::cerr << "OpenGL 4.1 is supported\n";
-            } else {
-                std::cerr << "OpenGL 4.1 is not supported\n";
-                std::cerr << "OpenGL 3.3 is " << ((GLAD_GL_VERSION_3_3) ? "" : "not ") << "supported\n";
-                std::cerr << "OpenGL 2.1 is " << ((GLAD_GL_VERSION_2_1) ? "" : "not ") << "supported\n";
+            if (debug) {
+                if (GLAD_GL_VERSION_4_1) {
+                    std::cerr << "OpenGL 4.1 is supported\n";
+                } else {
+                    std::cerr << "OpenGL 4.1 is not supported\n";
+                    std::cerr << "OpenGL 3.3 is " << ((GLAD_GL_VERSION_3_3) ? "" : "not ") << "supported\n";
+                    std::cerr << "OpenGL 2.1 is " << ((GLAD_GL_VERSION_2_1) ? "" : "not ") << "supported\n";
+                }
             }
         }
         if (debug) {
@@ -705,8 +711,8 @@ namespace Manager {
             Utils::Dims pos = Utils::parseDimensions(opts.seshIni["general"]["window_position"]);
             glfwSetWindowPos(window, pos.x, pos.y);
         }
-        glfwSetWindowSize(window, opts.dimensions.x, opts.dimensions.y);
-        windowResize(opts.dimensions.x, opts.dimensions.y);
+//        glfwSetWindowSize(window, opts.dimensions.x, opts.dimensions.y);
+//        windowResize(opts.dimensions.x, opts.dimensions.y);
         redraw = true;
     }
 
@@ -723,6 +729,9 @@ namespace Manager {
         }
         int xpos, ypos;
         glfwGetWindowPos(window, &xpos, &ypos);
+//        int windX = fb_width / monitorScale;
+//        int windY = fb_height / monitorScale;
+
         int windX, windY;
         glfwGetWindowSize(window, &windX, &windY);
         opts.saveCurrentSession(reference, ideogram_path, bam_paths, track_paths, regions, variant_paths_info,
@@ -730,6 +739,7 @@ namespace Manager {
     }
 
     int GwPlot::startUI(GrDirectContext *sContext, SkSurface *sSurface, int delay, std::vector<std::string> &extra_commands) {
+
         if (!opts.session_file.empty() && reference.empty()) {
             std::cout << "Loading session: " << opts.session_file << std::endl;
             loadSession();
@@ -743,7 +753,7 @@ namespace Manager {
 #if !defined(__EMSCRIPTEN__)
         Term::startVersionCheck();
 #endif
-
+        fonts.setOverlayHeight(monitorScale);
         vCursor = glfwCreateStandardCursor(GLFW_VRESIZE_CURSOR);
 	    normalCursor = glfwCreateStandardCursor(GLFW_ARROW_CURSOR);
 
@@ -787,7 +797,6 @@ namespace Manager {
 
             if (resizeTriggered && std::chrono::duration_cast<std::chrono::milliseconds>(
                     std::chrono::high_resolution_clock::now() - resizeTimer) > 100ms) {
-
                 redraw = true;
                 processed = false;
                 wasResized = true;
@@ -930,13 +939,14 @@ namespace Manager {
                     }
                     if (opts.max_coverage) {
                         collections[idx].covArr.resize(reg->end - reg->start + 1, 0);
-                        if (opts.snp_threshold > reg->end - reg->start) {
-                            collections[idx].mmVector.resize(reg->end - reg->start + 1);
-                            Segs::Mismatches empty_mm = {0, 0, 0, 0};
-                            std::fill(collections[idx].mmVector.begin(), collections[idx].mmVector.end(), empty_mm);
-                        } else if (!collections[idx].mmVector.empty()) {
-                            collections[idx].mmVector.clear();
-                        }
+
+                    }
+                    if (opts.snp_threshold > reg->end - reg->start) {
+                        collections[idx].mmVector.resize(reg->end - reg->start + 1);
+                        Segs::Mismatches empty_mm = {0, 0, 0, 0};
+                        std::fill(collections[idx].mmVector.begin(), collections[idx].mmVector.end(), empty_mm);
+                    } else if (!collections[idx].mmVector.empty()) {
+                        collections[idx].mmVector.clear();
                     }
 
                     if (reg->end - reg->start < opts.low_memory || opts.link_op != 0) {
@@ -973,7 +983,7 @@ namespace Manager {
             float xscale = 1;
             float yscale = 1;
             glfwGetWindowContentScale(window, &xscale, &yscale);
-            monitorScale = xscale;  // we assume xscale and yscale are the same
+            monitorScale = std::fmax(xscale, (float)1);  // we assume xscale and yscale are the same
             glfwGetFramebufferSize(window, &fb_width, &fb_height);
             if (monitorScale > 1) {
                 opts.theme.lcBright.setStrokeWidth(monitorScale);
@@ -982,45 +992,47 @@ namespace Manager {
             monitorScale = 1;
             glfwGetFramebufferSize(backWindow, &fb_width, &fb_height);
         }
-        gap = std::fmin(std::fmax(5, fb_height * 0.01 * monitorScale), monitorScale * 10);
-
+        gap = monitorScale * 10;
+        fonts.setOverlayHeight(monitorScale);
     }
 
-    void GwPlot::setRasterSize(int width, int height) {
-//        monitorScale = 1;
+    void GwPlot::setImageSize(int width, int height) {
         fb_width = width;
         fb_height = height;
-        gap = std::fmin(std::fmax(5, fb_height * 0.01 * monitorScale), monitorScale * 10);
+        gap = monitorScale * 10;
+        fonts.setOverlayHeight(monitorScale);
     }
 
     // sets scaling of y-position for various elements
     void GwPlot::setScaling() {  // todo only call this function when needed - fb size change, or when plot items are added or removed
-        fonts.setOverlayHeight(monitorScale);
 
-        refSpace =  fonts.overlayHeight + gap;
+        refSpace = fonts.overlayHeight * 2;
         if (opts.scale_bar) {
-            refSpace += fonts.overlayHeight + gap;
+            refSpace += fonts.overlayHeight * 2;
         }
         sliderSpace = std::fmax((float)(fb_height * 0.0175), 10*monitorScale) + (gap * 0.5);
         auto fbh = (float) fb_height;
         auto fbw = (float) fb_width;
-        if (bams.empty()) {
-            covY = 0; totalCovY = 0; totalTabixY = 0; tabixY = 0;
-        }
         auto nbams = (float)bams.size();
-        if (opts.max_coverage && nbams > 0) {
-            totalCovY = fbh * (float)0.1;
-            covY = totalCovY / nbams;
-        } else {
-            totalCovY = 0; covY = 0;
-        }
         if (tracks.empty()) {
             totalTabixY = 0; tabixY = 0;
         } else {
             totalTabixY = (fbh - refSpace - sliderSpace) * (float)opts.tab_track_height;
             tabixY = totalTabixY / (float)tracks.size();
         }
-        if (nbams > 0 && samMaxY > 0) {
+
+        if (nbams == 0 || opts.max_coverage == 0) {
+            covY = 0; totalCovY = 0; trackY = 0;
+        } else {
+            totalCovY = (fbh - refSpace - sliderSpace - totalTabixY - gap) * ((opts.alignments) ? (float)0.15 : 1);
+            covY = totalCovY / nbams;
+        }
+
+        if (!opts.alignments) {
+            yScaling = 0;
+            trackY = 0;
+            pH = 0;
+        } else if (nbams > 0 && samMaxY > 0) {
             trackY = (fbh - totalCovY - totalTabixY - refSpace - sliderSpace - gap) / nbams;
             yScaling = (trackY - gap) / (double)samMaxY;
 
@@ -1028,31 +1040,28 @@ namespace Manager {
             if (yScaling > 1) {
                 yScaling = std::ceil(yScaling);
             }
-        } else {
-            trackY = 0;
-            yScaling = 0;
-        }
 
-        if (opts.tlen_yscale) {
-            pH = trackY / (float) opts.ylim;
-            yScaling *= 0.95;
-        } else {
-            if (yScaling > 3*monitorScale) {
-                pH = yScaling - monitorScale;
+            if (opts.tlen_yscale) {
+                pH = trackY / (float) opts.ylim;
+                yScaling *= 0.95;
             } else {
-                pH = yScaling;
+                if (yScaling > 3*monitorScale) {
+                    pH = yScaling - monitorScale;
+                } else {
+                    pH = yScaling;
+                }
+            }
+
+            if (pH > 8) {  // scale to pixel boundary
+                pH = (float)(int)pH;
+            } else if (opts.tlen_yscale) {
+                pH = std::fmax(pH, 8);
             }
         }
 
-        if (pH > 8) {  // scale to pixel boundary
-            pH = (float)(int)pH;
-        } else if (opts.tlen_yscale) {
-            pH = std::fmax(pH, 8);
-        }
-
-        fonts.setFontSize(yScaling, monitorScale);
         regionWidth = fbw / (float)regions.size();
         bamHeight = covY + trackY;
+
         for (auto &cl: collections) {
             cl.xScaling = (float)((regionWidth - gap - gap) / ((double)(cl.region->end - cl.region->start)));
             cl.xOffset = (regionWidth * (float)cl.regionIdx) + gap;
@@ -1069,7 +1078,7 @@ namespace Manager {
         }
 
         pointSlop = (tan(0.45) * (yScaling * 0.5));  // radians
-        textDrop = std::fmax(0, (yScaling - fonts.fontHeight) * 0.5);
+        textDrop = std::fmax(0, (yScaling - fonts.overlayHeight) * 0.5);
 
         minGapSize = (uint32_t)(fb_width * 0.005);
         if (opts.parse_mods) {
@@ -1109,9 +1118,7 @@ namespace Manager {
         } else {
             processBam();  // Reads may be buffered here, or else streamed using the runDrawNoBuffer functions below
             setScaling();
-            if (yScaling == 0) {
-                return;
-            }
+
             SkRect clip;
             if (!imageCacheQueue.empty() && collections.size() > 1) {
                 canvasR->drawImage(imageCacheQueue.back().second, 0, 0);
@@ -1149,16 +1156,16 @@ namespace Manager {
                             HGW::iterDraw(cl, bams[cl.bamIdx], headers[cl.bamIdx], indexes[cl.bamIdx],
                                           &regions[cl.regionIdx], (bool) opts.max_coverage,
                                           filters, opts, canvasR, trackY, yScaling, fonts, refSpace, pointSlop,
-                                          textDrop, pH, monitorScale);
+                                          textDrop, pH, monitorScale, bam_paths);
                         } else {
                             HGW::iterDrawParallel(cl, bams[cl.bamIdx], headers[cl.bamIdx], indexes[cl.bamIdx],
                                                   opts.threads, &regions[cl.regionIdx], (bool) opts.max_coverage,
                                                   filters, opts, canvasR, trackY, yScaling, fonts, refSpace, pool,
-                                                  pointSlop, textDrop, pH, monitorScale);
+                                                  pointSlop, textDrop, pH, monitorScale, bam_paths);
                         }
                     } else {
                         Drawing::drawCollection(opts, cl, canvasR, trackY, yScaling, fonts, opts.link_op, refSpace,
-                                                pointSlop, textDrop, pH, monitorScale);
+                                                pointSlop, textDrop, pH, monitorScale, bam_paths);
                     }
                 }
                 canvasR->restore();
@@ -1166,7 +1173,7 @@ namespace Manager {
         }
 
         if (opts.max_coverage) {
-            Drawing::drawCoverage(opts, collections, canvasR, fonts, covY, refSpace, gap);
+            Drawing::drawCoverage(opts, collections, canvasR, fonts, covY, refSpace, gap, monitorScale, bam_paths);
         }
         Drawing::drawRef(opts, regions, fb_width, canvasR, fonts, fonts.overlayHeight, (float)regions.size(), gap, monitorScale, opts.scale_bar);
         Drawing::drawBorders(opts, fb_width, fb_height, canvasR, regions.size(), bams.size(), trackY, covY, (int)tracks.size(), totalTabixY, refSpace, gap, totalCovY);
@@ -1252,7 +1259,7 @@ namespace Manager {
             drawCursorPosOnRefSlider(canvas);
         }
 
-        // draw menu
+        // draw main settings menu
         if (mode == Show::SETTINGS) {
             if (!imageCacheQueue.empty()) {
                 while (imageCacheQueue.front().first != frameId) {
@@ -1344,9 +1351,8 @@ namespace Manager {
             }
         }
 
-        // command box
+        // command popup box
         if (captureText && !opts.editing_underway) {
-            fonts.setFontSize(yScaling, monitorScale);
             SkRect rect{};
             float height_f = fonts.overlayHeight * 2;
             float x = 25 * monitorScale;
@@ -1375,7 +1381,7 @@ namespace Manager {
             }
             float to_cursor_width = fonts.overlay.measureText(inputText2.substr(0, charIndex2).c_str(), charIndex2, SkTextEncoding::kUTF8);
             rect.setXYWH(0, yy, fb_width, fb_height);
-            canvas->drawRoundRect(rect, 5 * monitorScale, 5 * monitorScale, bg);
+            canvas->drawRect(rect, bg);
 
             // Cursor and text
             SkPath path;
@@ -1416,7 +1422,6 @@ namespace Manager {
                     canvas->drawRoundRect(rect, 10, 10, bg);
                 }
 
-
                 for (const auto &cmd : Menu::commandToolTip) {
                     std::string cmd_s = cmd;
                     if (!inputText.empty() && !Utils::startsWith(cmd_s, inputText)) {
@@ -1442,9 +1447,6 @@ namespace Manager {
                         canvas->drawPath(path, tip_paint);
                     }
                     yy -= fonts.overlayHeight + padT;
-                    if (yy < covY) {
-                        break;
-                    }
                 }
             }
         }
@@ -1496,7 +1498,7 @@ namespace Manager {
         }
 
         bool current_view_is_images = (!variantTracks.empty() && variantTracks[variantFileSelection].type == HGW::TrackType::IMAGES);
-        if (bams.empty() && !current_view_is_images && mode != SETTINGS) {
+        if (bams.empty() && !current_view_is_images && mode != SETTINGS && frameId < 10) {
             float trackBoundary = fb_height - totalTabixY - refSpace;
             std::string dd_msg = "Drag-and-drop bam or cram files here";
             float msg_width = fonts.overlay.measureText(dd_msg.c_str(), dd_msg.size(), SkTextEncoding::kUTF8);
@@ -1509,7 +1511,7 @@ namespace Manager {
             if (trackBoundary > (float)fb_height / 2) {
                 canvas->drawTextBlob(blob.get(), txt_start, (float)fb_height / 2, tcMenu);
             }
-        } else if (regions.empty() && !current_view_is_images && mode != SETTINGS) {
+        } else if (regions.empty() && !current_view_is_images && mode != SETTINGS && frameId < 10) {
             std::string dd_msg = "Open the command box ('/' key) and enter a chromosome name or location e.g. 'chr1'";
             float msg_width = fonts.overlay.measureText(dd_msg.c_str(), dd_msg.size(), SkTextEncoding::kUTF8);
             float txt_start = ((float)fb_width / 2) - (msg_width / 2);
@@ -1669,44 +1671,52 @@ namespace Manager {
         }
         canvas->drawPaint(opts.theme.bgPaint);
         SkRect clip;
+
         for (auto &cl: collections) {
-
-            canvas->save();
-
-            if (cl.bamIdx == 0) {  // cover the ref too
-                clip.setXYWH(cl.xOffset, 0, cl.regionPixels, cl.yOffset + trackY + covY + refSpace);
-            } else {
-                clip.setXYWH(cl.xOffset, cl.yOffset - covY, cl.regionPixels, cl.yOffset + trackY + covY);
+            if (cl.skipDrawingCoverage && cl.skipDrawingReads) {  // keep read and coverage area
+                continue;
             }
-            canvas->clipRect(clip, false);
+            canvas->save();
+            // for now cl.skipDrawingCoverage and cl.skipDrawingReads are almost always the same
+            if ((!cl.skipDrawingCoverage && !cl.skipDrawingReads) || imageCacheQueue.empty()) {
+                clip.setXYWH(cl.xOffset, cl.yOffset - covY, cl.regionPixels, trackY + covY - gap);
+                canvas->clipRect(clip, false);
+            } else if (cl.skipDrawingCoverage) {
+                clip.setXYWH(cl.xOffset, cl.yOffset, cl.regionPixels, cl.yPixels);
+                canvas->clipRect(clip, false);
+            } else if (cl.skipDrawingReads){
+                clip.setXYWH(cl.xOffset, cl.yOffset - covY, cl.regionPixels, covY);
+                canvas->clipRect(clip, false);
+            }  // else no clip
             canvas->drawPaint(opts.theme.bgPaint);
 
-            if (!cl.skipDrawingReads) {
+            if (!cl.skipDrawingReads && !bams.empty()) {
 
-                if (cl.regionLen >= opts.low_memory && !bams.empty() && opts.link_op == 0) {  // low memory mode will be used
+                if (cl.regionLen >= opts.low_memory) {
+                    assert (opts.link_op == 0 && regions[cl.regionIdx].getSortOption() == SortType::NONE);
+                    // low memory mode will be used
                     cl.clear();
                     if (opts.threads == 1) {
                         HGW::iterDraw(cl, bams[cl.bamIdx], headers[cl.bamIdx], indexes[cl.bamIdx],
                                       &regions[cl.regionIdx], (bool) opts.max_coverage,
                                       filters, opts, canvas, trackY, yScaling, fonts, refSpace, pointSlop,
-                                      textDrop, pH, monitorScale);
+                                      textDrop, pH, monitorScale, bam_paths);
                     } else {
                         HGW::iterDrawParallel(cl, bams[cl.bamIdx], headers[cl.bamIdx], indexes[cl.bamIdx],
                                               opts.threads, &regions[cl.regionIdx], (bool) opts.max_coverage,
                                               filters, opts, canvas, trackY, yScaling, fonts, refSpace, pool,
-                                              pointSlop, textDrop, pH, monitorScale);
+                                              pointSlop, textDrop, pH, monitorScale, bam_paths);
                     }
                 } else {
                     Drawing::drawCollection(opts, cl, canvas, trackY, yScaling, fonts, opts.link_op, refSpace,
-                                            pointSlop, textDrop, pH, monitorScale);
+                                            pointSlop, textDrop, pH, monitorScale, bam_paths);
                 }
             }
             canvas->restore();
-
-//            Drawing::drawCollection(opts, cl, canvas, trackY, yScaling, fonts, opts.link_op, refSpace, pointSlop, textDrop, pH, monitorScale);
         }
+
         if (opts.max_coverage) {
-            Drawing::drawCoverage(opts, collections, canvas, fonts, covY, refSpace, gap);
+            Drawing::drawCoverage(opts, collections, canvas, fonts, covY, refSpace, gap, monitorScale, bam_paths);
         }
         Drawing::drawRef(opts, regions, fb_width, canvas, fonts, fonts.overlayHeight, (float)regions.size(), gap, monitorScale, opts.scale_bar);
         Drawing::drawBorders(opts, fb_width, fb_height, canvas, regions.size(), bams.size(), trackY, covY, (int)tracks.size(), totalTabixY, refSpace, gap, totalCovY);
@@ -1720,7 +1730,6 @@ namespace Manager {
 
     void GwPlot::runDrawNoBufferOnCanvas(SkCanvas* canvas) {
 //        std::chrono::high_resolution_clock::time_point initial = std::chrono::high_resolution_clock::now();
-
         if (bams.empty()) {
             return;
         }
@@ -1745,13 +1754,13 @@ namespace Manager {
                 col.region = reg;
                 if (opts.max_coverage) {
                     col.covArr.resize(reg->end - reg->start + 1, 0);
-                    if (opts.snp_threshold > reg->end - reg->start) {
-                        col.mmVector.resize(reg->end - reg->start + 1);
-                        Segs::Mismatches empty_mm = {0, 0, 0, 0};
-                        std::fill(col.mmVector.begin(), col.mmVector.end(), empty_mm);
-                    } else if (!col.mmVector.empty()) {
-                        col.mmVector.clear();
-                    }
+                }
+                if (opts.snp_threshold > reg->end - reg->start) {
+                    col.mmVector.resize(reg->end - reg->start + 1);
+                    Segs::Mismatches empty_mm = {0, 0, 0, 0};
+                    std::fill(col.mmVector.begin(), col.mmVector.end(), empty_mm);
+                } else if (!col.mmVector.empty()) {
+                    col.mmVector.clear();
                 }
                 idx += 1;
             }
@@ -1791,24 +1800,22 @@ namespace Manager {
 
             if (!cl.skipDrawingReads) {
                 if (opts.threads == 1) {
-//                    std::chrono::high_resolution_clock::time_point initial = std::chrono::high_resolution_clock::now();
                     HGW::iterDraw(cl, bams[cl.bamIdx], headers[cl.bamIdx], indexes[cl.bamIdx],
                                   &regions[cl.regionIdx], (bool) opts.max_coverage,
                                   filters, opts, canvas, trackY, yScaling, fonts, refSpace, pointSlop,
-                                  textDrop, pH, monitorScale);
-//                    std::cerr << " time runDrawNoBufferOnCanvas " << (std::chrono::duration_cast<std::chrono::milliseconds >(std::chrono::high_resolution_clock::now() - initial).count()) << std::endl;
+                                  textDrop, pH, monitorScale, bam_paths);
                 } else {
                     HGW::iterDrawParallel(cl, bams[cl.bamIdx], headers[cl.bamIdx], indexes[cl.bamIdx],
                                           opts.threads, &regions[cl.regionIdx], (bool) opts.max_coverage,
                                           filters, opts, canvas, trackY, yScaling, fonts, refSpace, pool,
-                                          pointSlop, textDrop, pH, monitorScale);
+                                          pointSlop, textDrop, pH, monitorScale, bam_paths);
                 }
             }
             canvas->restore();
         }
 
         if (opts.max_coverage) {
-            Drawing::drawCoverage(opts, collections, canvas, fonts, covY, refSpace, gap);
+            Drawing::drawCoverage(opts, collections, canvas, fonts, covY, refSpace, gap, monitorScale, bam_paths);
         }
 
         Drawing::drawRef(opts, regions, fb_width, canvas, fonts, fonts.overlayHeight, (float)regions.size(), gap, monitorScale, opts.scale_bar);
