@@ -35,6 +35,7 @@ namespace Term {
         out << termcolor::underline << "\nCommand          Modifier        Description                                            \n" << termcolor::reset;
         out << termcolor::green << "[locus]                          " << termcolor::reset << "e.g. 'chr1' or 'chr1:1-20000'\n";
         out << termcolor::green << "add              region(s)       " << termcolor::reset << "Add one or more regions e.g. 'add chr1:1-20000'\n";
+        out << termcolor::green << "alignments                       " << termcolor::reset << "Turn display alignments on or off\n";
         out << termcolor::green << "colour           name + ARGB     " << termcolor::reset << "Set a colour for a plot component\n";
         out << termcolor::green << "count            expression?     " << termcolor::reset << "Count reads. See filter for example expressions'\n";
         out << termcolor::green << "cov              value?          " << termcolor::reset << "Change max coverage value. Use 'cov' to toggle coverage\n";
@@ -47,6 +48,7 @@ namespace Term {
         out << termcolor::green << "header           names?          " << termcolor::reset << "Prints the header of the current bam to terminal\n";
         out << termcolor::green << "indel-length     int             " << termcolor::reset << "Label indels >= length\n";
         out << termcolor::green << "insertions, ins                  " << termcolor::reset << "Toggle insertions\n";
+        out << termcolor::green << "label                            " << termcolor::reset << "Toggle data labels\n";
         out << termcolor::green << "line                             " << termcolor::reset << "Toggle mouse position vertical line\n";
         out << termcolor::green << "link             none/sv/all     " << termcolor::reset << "Switch read-linking 'link all'\n";
         out << termcolor::green << "load             type? file      " << termcolor::reset << "Load bams, tracks, tiles, session file or ideogram\n";
@@ -59,9 +61,9 @@ namespace Term {
         out << termcolor::green << "remove, rm       index           " << termcolor::reset << "Remove a region by index e.g. 'rm 1'. To remove a bam \n                                 use the bam index 'rm bam1', or track 'rm track1'\n";
         out << termcolor::green << "roi              region? name?   " << termcolor::reset << "Add a region of interest\n";
         out << termcolor::green << "sam                              " << termcolor::reset << "Print selected read to screen or save to file\n";
-        out << termcolor::green << "save             filename        " << termcolor::reset << "Save reads (bam/cram), snapshot (png), session (ini), or labels (tsv/txt)\n";
+        out << termcolor::green << "save             filename        " << termcolor::reset << "Save reads (bam/cram), snapshot (png/pdf/svg), session (ini), or labels (tsv)\n";
         out << termcolor::green << "settings                         " << termcolor::reset << "Open the settings menu'\n";
-		out << termcolor::green << "snapshot, s      path?           " << termcolor::reset << "Save current window to png e.g. 's', or 's view.png',\n                                 or vcf columns can be used 's {pos}_{info.SU}.png'\n";
+		out << termcolor::green << "snapshot, s      path?           " << termcolor::reset << "Save current window as image e.g. 's', or 's view.png',\n                                 or vcf columns can be used 's {pos}_{info.SU}.png'\n";
         out << termcolor::green << "soft-clips, sc                   " << termcolor::reset << "Toggle soft-clips\n";
         out << termcolor::green << "sort             strand/hap/pos  " << termcolor::reset << "Sort reads by strand, haplotype, and/or pos\n";
         out << termcolor::green << "tags                             " << termcolor::reset << "Print selected sam tags\n";
@@ -99,6 +101,8 @@ namespace Term {
             out << "    Navigate to a genomic locus.\n        You can use chromosome names or chromosome coordinates.\n    Examples:\n        'chr1:1-20000', 'chr1', 'chr1:10000'\n\n";
         } else if (s == "add") {
             out << "    Add a genomic locus.\n        This will add a new locus to the right-hand-side of your view.\n    Examples:\n        'add chr1:1-20000', 'add chr2'\n\n";
+        } else if (s == "alignments") {
+            out << "    Toggle alignments.\n        Alignments will be shown or hidden.\n\n";
         } else if (s == "colour" || s == "color") {
             out << "    Set the (alpha, red, green, blue) colour for one of the plot elements.\n"
                    "        Elements are selected by name (see below) and values are in the range [0, 255].\n"
@@ -197,6 +201,8 @@ namespace Term {
             out << "    Set the minimum indel-length.\n        Indels (gaps in alignments) will be labelled with text if they have length >= 'indel-length'\n    Examples:\n        'indel-length 30'\n\n";
         } else if (s == "insertions" || s == "ins") {
             out << "    Toggle insertions.\n        Insertions smaller than 'indel-length' are turned on or off.\n\n";
+        } else if (s == "labels") {
+            out << "    Toggle data labels.\n        Text labels will be displayed next to data tracks.\n\n";
         } else if (s == "line") {
             out << "    Toggle line.\n        A vertical line will turn on/off.\n\n";
         } else if (s == "link" || s == "l") {
@@ -256,7 +262,7 @@ namespace Term {
                          "        'save reads.bam [0, 1]' # Indexing can be used - here reads from row 0, column 1 will be saved\n"
                          "        'save reads.cram'       # Reads saved in cram format\n"
                          "        'save reads.sam'        # Reads saved in sam format (human readable)\n\n"
-                         "        'save view.png'         # The current view is saved to view.png. Same functionality as 'snapshot'\n"
+                         "        'save view.pdf'         # The current view is saved to view.png. Same functionality as 'snapshot'\n"
                          "        'save session.ini'      # The current session will be saved, allowing this session to be revisited\n"
                          "        'save labels.tsv'       # The output label file will be saved here\n\n"
                          "    Notes:\n"
@@ -269,6 +275,7 @@ namespace Term {
             out << "    Save an image of the screen.\n"
                          "        Saves current window. If no name is provided, the image name will be 'chrom_start_end.png', \n"
                          "        or if you are in tile-mode, the image name will be 'index_start_end.png'.\n"
+                         "        Supported file extensions are .png, .pdf and .svg\n"
                          "            snapshot\n"
                          "            snapshot my_image.png\n\n"
                          "        If you have a vcf/bcf open in 'single' mode (not 'tiled') it is also possible to parse info\n"
@@ -817,7 +824,7 @@ namespace Term {
             if (s == nullptr) {
                 return;
             }
-            out << "\n\n" << region->chrom << ":" << region->start << "-" << region->end << "\n";
+            out << "\n\n>" << region->chrom << ":" << region->start << "-" << region->end << "\n";
             while (*s) {
                 switch ((unsigned int)*s) {
                     case 65: out << termcolor::green << "a"; break;
@@ -870,10 +877,14 @@ namespace Term {
 			if ((int)bnd->pos <= pos && pos <= (int)bnd->reference_end) {
 				Segs::Align &align = *bnd;
 				uint32_t r_pos = align.pos;
+                if (align.delegate == nullptr) {
+                    --bnd;
+                    continue;
+                }
 				uint32_t cigar_l = align.delegate->core.n_cigar;
 				uint8_t *ptr_seq = bam_get_seq(align.delegate);
 				uint32_t *cigar_p = bam_get_cigar(align.delegate);
-                if (cigar_p == nullptr || cigar_l == 0) {
+                if (cigar_p == nullptr || cigar_l == 0 || ptr_seq == nullptr) {
                     if (bnd == cl.readQueue.begin()) {
                         break;
                     }
@@ -1044,6 +1055,7 @@ namespace Term {
             return;
         }
 		int target = (int)((float)(rgn->end - rgn->start) * x) + rgn->start;
+        int jitter = (rgn->end - rgn->start) * 0.025;
 		std::filesystem::path p = track.path;
         bool isGFF = (track.kind == HGW::FType::GFF3_NOI || track.kind == HGW::FType::GFF3_IDX || track.kind == HGW::FType::GTF_NOI || track.kind == HGW::FType::GTF_IDX );
         if (trackIdx >= (int)rgn->featuresInView.size()) {
@@ -1051,7 +1063,7 @@ namespace Term {
         }
         bool same_pos, same_name = false;
         for (auto &b : rgn->featuresInView.at(trackIdx)) {
-            if (b.start <= target && b.end >= target && b.level == targetLevel) {
+            if (b.start - jitter <= target && b.end + jitter >= target && b.level == targetLevel) {
                 clearLine(out);
                 if (target_name == b.name) {
                     same_name = true;
@@ -1390,7 +1402,7 @@ namespace Term {
     }
 
 #if !defined(__EMSCRIPTEN__)
-    const char* CURRENT_VERSION = "v1.1.0";
+    const char* CURRENT_VERSION = "v1.1.1";
 
     size_t WriteCallback(void* contents, size_t size, size_t nmemb, void* userp) {
         ((std::string*)userp)->append((char*)contents, size * nmemb);
