@@ -21,7 +21,8 @@ namespace Themes {
 
     EXPORT BaseTheme::BaseTheme() {
 
-        fcCoverage.setStyle(SkPaint::kStrokeAndFill_Style);
+//        fcCoverage.setStyle(SkPaint::kStrokeAndFill_Style);
+        fcCoverage.setStyle(SkPaint::kFill_Style);
         fcCoverage.setStrokeWidth(0);
 
         // Set ARGB values directly for each SkPaint object in the mate_fc vector
@@ -432,6 +433,8 @@ namespace Themes {
         sv_arcs = true;
         parse_mods = false;
         scale_bar = true;
+        alignments = true;
+        data_labels = true;
 
         scroll_speed = 0.15;
         tab_track_height = 0.25;
@@ -516,6 +519,12 @@ namespace Themes {
             sub["scale_bar"] = "true";
             update_ini = true;
         }
+        if (sub.has("data_labels")) {
+            data_labels = sub["data_labels"] == "true";
+        } else {
+            sub["data_labels"] = "false";
+            update_ini = true;
+        }
         if (sub.has("sv_arcs")) {
             sv_arcs = sub["sv_arcs"] == "true";
         } else {
@@ -737,6 +746,12 @@ namespace Themes {
             if (sub.has("scale_bar")) {
                 scale_bar = sub["scale_bar"] == "true";
             }
+            if (sub.has("alignments")) {
+                alignments = sub["alignments"] == "true";
+            }
+            if (sub.has("data_labels")) {
+                data_labels = sub["data_labels"] == "true";
+            }
             if (sub.has("link")) {
                 link = sub["link"];
                 link_op = 0;
@@ -965,6 +980,8 @@ namespace Themes {
         sub["log2_cov"] = (log2_cov) ? "true" : "false";
         sub["expand_tracks"] = (expand_tracks) ? "true" : "false";
         sub["scale_bar"] = (scale_bar) ? "true" : "false";
+        sub["alignments"] = (alignments) ? "true" : "false";
+        sub["data_labels"] = (data_labels) ? "true" : "false";
         sub["mods"] = (parse_mods) ? "true" : "false";
         sub["link"] = link;
         sub["split_view_size"] = std::to_string(split_view_size);
@@ -1011,8 +1028,8 @@ namespace Themes {
     EXPORT Fonts::Fonts() {
         rect = SkRect::MakeEmpty();
         path = SkPath();
-        fontMaxSize = 35; // in pixels
-        fontHeight = 0;
+//        fontMaxSize = 35; // in pixels
+//        fontHeight = 0;
     }
 
     void Fonts::setTypeface(std::string &fontStr, int size) {
@@ -1048,8 +1065,8 @@ namespace Themes {
         }
 
         SkScalar ts = size;
-        fonty.setSize(ts);
-        fonty.setTypeface(face);
+//        fonty.setSize(ts);
+//        fonty.setTypeface(face);
         overlay.setSize(ts);
         overlay.setTypeface(face);
         fontTypefaceSize = size;
@@ -1063,43 +1080,54 @@ namespace Themes {
         overlay.getBounds(glyphs, 1, bounds, pnt);
         overlayHeight = bounds[0].height();
         overlayWidth = overlay.measureText("9", 1, SkTextEncoding::kUTF8);
+        SkScalar w = overlay.measureText("9", 1, SkTextEncoding::kUTF8);
+        for (int i = 0; i < 10; ++i) {
+            textWidths[i] = (float)w * (i + 1);
+        }
     }
 
-    void Fonts::setFontSize(float maxHeight, float yScale) {
-        SkRect bounds[1];
-        SkPaint paint1;
-        const SkPaint* pnt = &paint1;
-        SkScalar height;
-        int font_size = fontTypefaceSize * yScale;
-        fonty.setSize(font_size * yScale);
-        fonty.getBounds(glyphs, 1, bounds, pnt);
-        fontMaxSize = bounds[0].height();
-        bool was_set = false;
-        while (font_size > 8 * yScale) {
-            fonty.setSize(font_size);
-            fonty.getBounds(glyphs, 1, bounds, pnt);
-            height = bounds[0].height();
-            if (height < maxHeight*1.9) {
-                was_set = true;
-                break;
-            }
-            --font_size;
-        }
-        if (!was_set) {
-            fontSize = fontTypefaceSize * yScale;
-            fontHeight = fontMaxSize;
-            for (auto &i : textWidths) {
-                i = 0;
-            }
-        } else {
-            fontSize = (float)font_size;
-            fontHeight = height;
-            SkScalar w = fonty.measureText("9", 1, SkTextEncoding::kUTF8);
-            for (int i = 0; i < 10; ++i) {
-                textWidths[i] = (float)w * (i + 1);
-            }
-        }
-    }
+//    void Fonts::setFontSize(float maxHeight, float yScale) {
+//        SkRect bounds[1];
+//        SkPaint paint1;
+//        const SkPaint* pnt = &paint1;
+//        SkScalar height;
+//        int font_size = fontTypefaceSize * yScale;
+//        fonty.setSize(font_size * yScale);
+//        fonty.getBounds(glyphs, 1, bounds, pnt);
+//        fontMaxSize = bounds[0].height();
+//        fontSize = (float)font_size;
+//        fontHeight = bounds[0].height();
+//        SkScalar w = fonty.measureText("9", 1, SkTextEncoding::kUTF8);
+//        for (int i = 0; i < 10; ++i) {
+//            textWidths[i] = (float)w * (i + 1);
+//        }
+
+//        bool was_set = false;
+//        while (font_size > 8 * yScale) {
+//            fonty.setSize(font_size);
+//            fonty.getBounds(glyphs, 1, bounds, pnt);
+//            height = bounds[0].height();
+//            if (height < maxHeight*1.9) {
+//                was_set = true;
+//                break;
+//            }
+//            --font_size;
+//        }
+//        if (!was_set) {
+//            fontSize = fontTypefaceSize * yScale;
+//            fontHeight = fontMaxSize;
+//            for (auto &i : textWidths) {
+//                i = 0;
+//            }
+//        } else {
+//            fontSize = (float)font_size;
+//            fontHeight = height;
+//            SkScalar w = fonty.measureText("9", 1, SkTextEncoding::kUTF8);
+//            for (int i = 0; i < 10; ++i) {
+//                textWidths[i] = (float)w * (i + 1);
+//            }
+//        }
+//    }
 
     #define next_t std::getline(iss, token, '\t')
 
